@@ -1,5 +1,5 @@
 #if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: browse.c 788 2007-11-06 23:51:13Z hubert@u.washington.edu $";
+static char rcsid[] = "$Id: browse.c 848 2007-12-06 19:57:49Z hubert@u.washington.edu $";
 #endif
 
 /*
@@ -171,19 +171,19 @@ static char *BrowseHelpText[] = {
    should be left in front of the characters they cause to be bold. */
 N_("Help for Browse Command"),
 "  ",
-N_("\tPico's file browser is used to select a file from the"),
-N_("\tfile system for inclusion in the edited text."),
+N_("        Pico's file browser is used to select a file from the"),
+N_("        file system for inclusion in the edited text."),
 "  ",
-N_("~\tBoth directories and files are displayed.  Press ~S"),
-N_("~\tor ~R~e~t~u~r~n to select a file or directory.  When a file"),
-N_("\tis selected during the \"Read File\" command, it is"),
-N_("\tinserted into edited text.  Answering \"yes\" to the"),
-N_("\tverification question after a directory is selected causes"),
-N_("\tthe contents of that directory to be displayed for selection."),
+N_("~        Both directories and files are displayed.  Press ~S"),
+N_("~        or ~R~e~t~u~r~n to select a file or directory.  When a file"),
+N_("        is selected during the \"Read File\" command, it is"),
+N_("        inserted into edited text.  Answering \"yes\" to the"),
+N_("        verification question after a directory is selected causes"),
+N_("        the contents of that directory to be displayed for selection."),
 "  ",
-N_("\tThe file named \"..\" is special, and means the \"parent\""),
-N_("\tof the directory being displayed.  Select this directory"),
-N_("\tto move upward in the directory tree."),
+N_("        The file named \"..\" is special, and means the \"parent\""),
+N_("        of the directory being displayed.  Select this directory"),
+N_("        to move upward in the directory tree."),
 "  ",
 N_("End of Browser Help."),
 "  ",
@@ -197,42 +197,42 @@ static char *sa_BrowseHelpText[] = {
 /* TRANSLATORS: Some more help text */
 N_("Help for Pilot (PIne's Looker-upper Of Things"),
 " ",
-N_("\tPilot is a simple, display-oriented file system browser based on the"),
-N_("~\tAlpine message system composer.  As with Alpine, commands are displayed at"),
-N_("~\tthe bottom of the screen, and context-sensitive help is provided."),
+N_("        Pilot is a simple, display-oriented file system browser based on the"),
+N_("~        Alpine message system composer.  As with Alpine, commands are displayed at"),
+N_("~        the bottom of the screen, and context-sensitive help is provided."),
 " ",
-N_("~\tPilot displays the current working directory at the top of the screen."),
-N_("~\tThe directory's contents are displayed in columns of file name, file"),
-N_("~\tsize pairs.  Names that are directories are indicated by the name"),
-N_("~\t~(~d~i~r~) in place of the file size.  The parent of the current working"),
-N_("~\tdirectory is indicated by the file name ~.~. and size of ~(~p~a~r~e~n~t~ ~d~i~r~)."),
-N_("~\tFile names that are symbolic links to other files are displayed with a"),
-N_("~\tfile size of ~-~-."),
+N_("~        Pilot displays the current working directory at the top of the screen."),
+N_("~        The directory's contents are displayed in columns of file name, file"),
+N_("~        size pairs.  Names that are directories are indicated by the name"),
+N_("~        ~(~d~i~r~) in place of the file size.  The parent of the current working"),
+N_("~        directory is indicated by the file name ~.~. and size of ~(~p~a~r~e~n~t~ ~d~i~r~)."),
+N_("~        File names that are symbolic links to other files are displayed with a"),
+N_("~        file size of ~-~-."),
 " ",
-N_("\tThe following function keys are available in Pilot:"),
+N_("        The following function keys are available in Pilot:"),
 " ",
-N_("~\t~?\tDisplay this help text."),
-N_("~\t~Q\tQuit Pilot."),
+N_("~        ~?        Display this help text."),
+N_("~        ~Q        Quit Pilot."),
 " ",
-N_("~\t~V\tView the currently selected file or open the selected directory."),
-N_("~\t\tNote: Pilot invokes ~p~i~n~e ~-~F, or the program defined by the ~P~A~G~E~R"),
-N_("~\t\t      environment variable, to view the file."),
-N_("~\t~L\tLaunch an external application program."),
+N_("~        ~V        View the currently selected file or open the selected directory."),
+N_("~                Note: Pilot invokes ~p~i~n~e ~-~F, or the program defined by the ~P~A~G~E~R"),
+N_("~                      environment variable, to view the file."),
+N_("~        ~L        Launch an external application program."),
 " ",
-N_("~\t~W\tSearch for a file by name."),
-N_("~\t~-\tScroll up one page."),
-N_("~\t~S~p~a~c~e\tScroll down one page."),
-N_("~\t~N,~^~F\tMove forward (right) one column."),
-N_("~\t~P,~^~B\tMove back (left) one column."),
-N_("~\t~^~N\tMove down one row."),
-N_("~\t~^~P\tMove up one row."),
+N_("~        ~W        Search for a file by name."),
+N_("~        ~-        Scroll up one page."),
+N_("~        ~S~p~a~c~e        Scroll down one page."),
+N_("~        ~N,~^~F        Move forward (right) one column."),
+N_("~        ~P,~^~B        Move back (left) one column."),
+N_("~        ~^~N        Move down one row."),
+N_("~        ~^~P        Move up one row."),
 " ",
-N_("~\t~D\tDelete the selected file."),
-N_("~\t~R\tRename the selected file or directory."),
-N_("~\t~C\tCopy the selected file."),
-N_("~\t~E\tEdit the selected file."),
-N_("~\t\tNote: Pilot invokes ~p~i~c~o, or the program defined by the ~E~D~I~T~O~R"),
-N_("~\t\t      environment variable, to edit the file."),
+N_("~        ~D        Delete the selected file."),
+N_("~        ~R        Rename the selected file or directory."),
+N_("~        ~C        Copy the selected file."),
+N_("~        ~E        Edit the selected file."),
+N_("~                Note: Pilot invokes ~p~i~c~o, or the program defined by the ~E~D~I~T~O~R"),
+N_("~                      environment variable, to edit the file."),
 " ",
 N_("End of Pilot Help."),
 NULL
